@@ -1,9 +1,9 @@
-from __future__ import annotations
-
-from asyncio import CancelledError
+from concurrent.futures import CancelledError
 from typing import TYPE_CHECKING, Any, Final, List, Optional, Union
 
-from robotcode.core.async_tools import async_tasking_event, threaded
+from robotcode.core.concurrent import check_current_task_canceled
+from robotcode.core.event import event
+from robotcode.core.language import language_id_filter
 from robotcode.core.lsp.types import (
     DefinitionParams,
     Location,
@@ -12,27 +12,29 @@ from robotcode.core.lsp.types import (
     ServerCapabilities,
     TextDocumentIdentifier,
 )
+from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
 from robotcode.jsonrpc2.protocol import rpc_method
-from robotcode.language_server.common.decorators import language_id_filter
-from robotcode.language_server.common.has_extend_capabilities import HasExtendCapabilities
-from robotcode.language_server.common.parts.protocol_part import LanguageServerProtocolPart
-from robotcode.language_server.common.text_document import TextDocument
+from robotcode.language_server.common.parts.protocol_part import (
+    LanguageServerProtocolPart,
+)
 
 if TYPE_CHECKING:
     from robotcode.language_server.common.protocol import LanguageServerProtocol
 
 
-class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
+class DefinitionProtocolPart(LanguageServerProtocolPart):
     _logger: Final = LoggingDescriptor()
 
-    def __init__(self, parent: LanguageServerProtocol) -> None:
+    def __init__(self, parent: "LanguageServerProtocol") -> None:
         super().__init__(parent)
         self.link_support = False
 
-    @async_tasking_event
-    async def collect(
-        sender, document: TextDocument, position: Position  # NOSONAR
+    @event
+    def collect(
+        sender,
+        document: TextDocument,
+        position: Position,
     ) -> Union[Location, List[Location], List[LocationLink], None]:
         ...
 
@@ -47,10 +49,13 @@ class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         if len(self.collect):
             capabilities.definition_provider = True
 
-    @rpc_method(name="textDocument/definition", param_type=DefinitionParams)
-    @threaded()
-    async def _text_document_definition(
-        self, text_document: TextDocumentIdentifier, position: Position, *args: Any, **kwargs: Any
+    @rpc_method(name="textDocument/definition", param_type=DefinitionParams, threaded=True)
+    def _text_document_definition(
+        self,
+        text_document: TextDocumentIdentifier,
+        position: Position,
+        *args: Any,
+        **kwargs: Any,
     ) -> Optional[Union[Location, List[Location], List[LocationLink]]]:
         locations: List[Location] = []
         location_links: List[LocationLink] = []
@@ -59,9 +64,14 @@ class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         if document is None:
             return None
 
-        for result in await self.collect(
-            self, document, document.position_from_utf16(position), callback_filter=language_id_filter(document)
+        for result in self.collect(
+            self,
+            document,
+            document.position_from_utf16(position),
+            callback_filter=language_id_filter(document),
         ):
+            check_current_task_canceled()
+
             if isinstance(result, BaseException):
                 if not isinstance(result, CancelledError):
                     self._logger.exception(result, exc_info=result)
