@@ -1,9 +1,9 @@
-from __future__ import annotations
-
-from asyncio import CancelledError
+from concurrent.futures import CancelledError
 from typing import TYPE_CHECKING, Any, Final, List, Optional
 
-from robotcode.core.async_tools import async_tasking_event, threaded
+from robotcode.core.concurrent import check_current_task_canceled
+from robotcode.core.event import event
+from robotcode.core.language import language_id_filter
 from robotcode.core.lsp.types import (
     Position,
     SelectionRange,
@@ -12,11 +12,9 @@ from robotcode.core.lsp.types import (
     ServerCapabilities,
     TextDocumentIdentifier,
 )
+from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
 from robotcode.jsonrpc2.protocol import rpc_method
-from robotcode.language_server.common.decorators import language_id_filter
-from robotcode.language_server.common.has_extend_capabilities import HasExtendCapabilities
-from robotcode.language_server.common.text_document import TextDocument
 
 if TYPE_CHECKING:
     from robotcode.language_server.common.protocol import LanguageServerProtocol
@@ -24,25 +22,22 @@ if TYPE_CHECKING:
 from .protocol_part import LanguageServerProtocolPart
 
 
-class SelectionRangeProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
+class SelectionRangeProtocolPart(LanguageServerProtocolPart):
     _logger: Final = LoggingDescriptor()
 
-    def __init__(self, parent: LanguageServerProtocol) -> None:
+    def __init__(self, parent: "LanguageServerProtocol") -> None:
         super().__init__(parent)
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
         if len(self.collect):
             capabilities.selection_range_provider = SelectionRangeOptions(work_done_progress=True)
 
-    @async_tasking_event
-    async def collect(
-        sender, document: TextDocument, positions: List[Position]  # NOSONAR
-    ) -> Optional[List[SelectionRange]]:
+    @event
+    def collect(sender, document: TextDocument, positions: List[Position]) -> Optional[List[SelectionRange]]:
         ...
 
-    @rpc_method(name="textDocument/selectionRange", param_type=SelectionRangeParams)
-    @threaded()
-    async def _text_document_selection_range(
+    @rpc_method(name="textDocument/selectionRange", param_type=SelectionRangeParams, threaded=True)
+    def _text_document_selection_range(
         self,
         text_document: TextDocumentIdentifier,
         positions: List[Position],
@@ -55,12 +50,14 @@ class SelectionRangeProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
         if document is None:
             return None
 
-        for result in await self.collect(
+        for result in self.collect(
             self,
             document,
             [document.position_from_utf16(p) for p in positions],
             callback_filter=language_id_filter(document),
         ):
+            check_current_task_canceled()
+
             if isinstance(result, BaseException):
                 if not isinstance(result, CancelledError):
                     self._logger.exception(result, exc_info=result)
@@ -76,7 +73,7 @@ class SelectionRangeProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
             if selection_range.parent is not None:
                 traverse(selection_range.parent, doc)
 
-        for result in results:
-            traverse(result, document)
+        for r in results:
+            traverse(r, document)
 
         return results
